@@ -15,7 +15,7 @@
         dcf <- read.dcf(file.path(lib, pkg, "DESCRIPTION"))
         msg <- gettextf("%s (%s %s)", dcf[, "Title"],
                         as.character(dcf[, "Version"]), dcf[, "Date"])
-        message(paste(strwrap(msg), collapse = "\n"))
+        packageStartupMessage(paste(strwrap(msg), collapse = "\n"))
 }
 
 .configEnv <- new.env()
